summaryrefslogtreecommitdiffstats
path: root/parts/documentation/protocols
diff options
context:
space:
mode:
Diffstat (limited to 'parts/documentation/protocols')
-rw-r--r--parts/documentation/protocols/chm/chm.cpp2
-rw-r--r--parts/documentation/protocols/chm/decompress.cpp30
-rw-r--r--parts/documentation/protocols/chm/kchmpart.cpp6
-rw-r--r--parts/documentation/protocols/chm/kchmpart.h4
4 files changed, 21 insertions, 21 deletions
diff --git a/parts/documentation/protocols/chm/chm.cpp b/parts/documentation/protocols/chm/chm.cpp
index e40ad5a9..e1528d03 100644
--- a/parts/documentation/protocols/chm/chm.cpp
+++ b/parts/documentation/protocols/chm/chm.cpp
@@ -76,7 +76,7 @@ ChmProtocol::~ChmProtocol()
void ChmProtocol::get( const KURL& url )
{
/** When :catalog is appended to the end, a plain-text representation of the catalog
- * is given out where each entry consists of four lines, an integer representing the tqparent
+ * is given out where each entry consists of four lines, an integer representing the parent
* of the node, an integer representing a node's ID, the Title of the Node, and it's hyperlink.
* When :contents is appended, all contained htm- and html-files will be printed, each in a line.
*/
diff --git a/parts/documentation/protocols/chm/kchmpart.cpp b/parts/documentation/protocols/chm/kchmpart.cpp
index 951c718a..b1d9d166 100644
--- a/parts/documentation/protocols/chm/kchmpart.cpp
+++ b/parts/documentation/protocols/chm/kchmpart.cpp
@@ -35,8 +35,8 @@ extern "C"
KInstance* KChmPartFactory::s_instance = 0L;
KAboutData* KChmPartFactory::s_about = 0L;
-KChmPartFactory::KChmPartFactory( TQObject* tqparent, const char* name )
- : KParts::Factory( tqparent, name )
+KChmPartFactory::KChmPartFactory( TQObject* parent, const char* name )
+ : KParts::Factory( parent, name )
{
}
@@ -66,7 +66,7 @@ KInstance* KChmPartFactory::instance()
}
-KChmPart::KChmPart( TQWidget * tqparent, const char * name )
+KChmPart::KChmPart( TQWidget * parent, const char * name )
: KDevHTMLPart( ), m_job(0)
{
KInstance * instance = new KInstance( "kchmpart" );
diff --git a/parts/documentation/protocols/chm/kchmpart.h b/parts/documentation/protocols/chm/kchmpart.h
index 7cbda958..7b5209fd 100644
--- a/parts/documentation/protocols/chm/kchmpart.h
+++ b/parts/documentation/protocols/chm/kchmpart.h
@@ -35,12 +35,12 @@ class KChmPartFactory: public KParts::Factory
Q_OBJECT
TQ_OBJECT
public:
- KChmPartFactory( TQObject *tqparent = 0, const char *name = 0 );
+ KChmPartFactory( TQObject *parent = 0, const char *name = 0 );
virtual ~KChmPartFactory();
virtual KParts::Part* createPartObject(
TQWidget *parentWidget, const char *widgetName,
- TQObject *tqparent, const char *name,
+ TQObject *parent, const char *name,
const char *classname, const TQStringList &args );
static KInstance *instance();
diff --git a/parts/documentation/protocols/chm/decompress.cpp b/parts/documentation/protocols/chm/decompress.cpp
index 212eb244..f411e8ec 100644
--- a/parts/documentation/protocols/chm/decompress.cpp
+++ b/parts/documentation/protocols/chm/decompress.cpp
@@ -228,7 +228,7 @@ int LZXinit(int window) {
* REMOVE_BITS(n) removes N bits from the bit buffer
*
* These bit access routines work by using the area beyond the MSB and the
* LSB as a free source of zeroes. This avoids having to tqmask any bits.
* So we have to know the bit width of the bitbuffer variable. This is
* sizeof(ULONG) * 8, also defined as ULONG_BITS
*/
@@ -328,9 +328,9 @@ int make_decode_table(ULONG nsyms, ULONG nbits, UBYTE *length, UWORD *table) {
register UBYTE bit_num = 1;
ULONG fill;
ULONG pos = 0; /* the current position in the decode table */
- ULONG table_tqmask = 1 << nbits;
- ULONG bit_tqmask = table_tqmask >> 1; /* don't do 0 length codes */
- ULONG next_symbol = bit_tqmask; /* base of allocation for long codes */
+ ULONG table_mask = 1 << nbits;
+ ULONG bit_mask = table_mask >> 1; /* don't do 0 length codes */
+ ULONG next_symbol = bit_mask; /* base of allocation for long codes */
/* fill entries for codes short enough for a direct mapping */
while (bit_num <= nbits)
@@ -341,27 +341,27 @@ int make_decode_table(ULONG nsyms, ULONG nbits, UBYTE *length, UWORD *table) {
{
leaf = pos;
- if ((pos += bit_tqmask) > table_tqmask) return 1; /* table overrun */
+ if ((pos += bit_mask) > table_mask) return 1; /* table overrun */
/* fill all possible lookups of this symbol with the symbol itself */
- fill = bit_tqmask;
+ fill = bit_mask;
while (fill-- > 0) table[leaf++] = sym;
}
}
- bit_tqmask >>= 1;
+ bit_mask >>= 1;
bit_num++;
}
/* if there are any codes longer than nbits */
- if (pos != table_tqmask)
+ if (pos != table_mask)
{
/* clear the remainder of the table */
- for (sym = pos; sym < table_tqmask; sym++) table[sym] = 0;
+ for (sym = pos; sym < table_mask; sym++) table[sym] = 0;
/* give ourselves room for codes to grow by up to 16 more bits */
pos <<= 16;
- table_tqmask <<= 16;
- bit_tqmask = 1 << 15;
+ table_mask <<= 16;
+ bit_mask = 1 << 15;
while (bit_num <= 16)
{
@@ -385,16 +385,16 @@ int make_decode_table(ULONG nsyms, ULONG nbits, UBYTE *length, UWORD *table) {
}
table[leaf] = sym;
- if ((pos += bit_tqmask) > table_tqmask) return 1; /* table overflow */
+ if ((pos += bit_mask) > table_mask) return 1; /* table overflow */
}
}
- bit_tqmask >>= 1;
+ bit_mask >>= 1;
bit_num++;
}
}
/* full table? */
- if (pos == table_tqmask) return 0;
+ if (pos == table_mask) return 0;
/* either erroneous table, or all elements are 0 - let's find out. */
for (sym = 0; sym < nsyms; sym++) if (length[sym]) return 1;
@@ -555,7 +555,7 @@ int LZXdecompress(UBYTE* inpos, int inlen, UBYTE* outpos, int outlen) {
togo -= this_run;
LZX(block_remaining) -= this_run;
- /* apply 2^x-1 tqmask */
+ /* apply 2^x-1 mask */
window_posn &= window_size - 1;
/* runs can't straddle the window wraparound */
if ((window_posn + this_run) > window_size)
@@ -228,7 +228,7 @@ int LZXinit(int window) {
*
* These bit access routines work by using the area beyond the MSB and the
- * LSB as a free source of zeroes. This avoids having to tqmask any bits.
+ * LSB as a free source of zeroes. This avoids having to mask any bits.
* So we have to know the bit width of the bitbuffer variable. This is
* sizeof(ULONG) * 8, also defined as ULONG_BITS